@@ -2,11 +2,15 @@
 pub mod bank;
 /// Oracle API Transactions
 pub mod oracle;
+/// messages around staking
 pub mod staking;
+/// regulat contract interactions
+pub mod wasm;
 
 use crate::core_types::MsgInternal;
 pub use bank::MsgSend;
 use serde::Serialize;
+pub use wasm::MsgExecuteContract;
 
 #[derive(Serialize)]
 /// Message: Send N coins from an address to another
